==> selenium-remote-driver-4.7.0.jar: META-INF/versions/9/module-info.java <==
module org.seleniumhq.selenium.remote_driver {
    requires io.netty.buffer;
    requires io.netty.codec.http;
    requires io.netty.common;
    requires io.netty.transport;
    requires io.netty.transport.classes.epoll;
    requires io.netty.transport.classes.kqueue;
    requires io.netty.transport.unix.common;
    requires io.opentelemetry.sdk;
    requires io.opentelemetry.sdk.autoconfigure;
    requires io.opentelemetry.sdk.autoconfigure.spi;
    requires io.opentelemetry.sdk.common;
    requires io.opentelemetry.semconv;
    requires net.bytebuddy;
    requires org.seleniumhq.selenium.manager;
    requires processed.commons.exec;
    requires processed.jtoml;
    /* transitive */ requires com.google.common;
    /* transitive */ requires io.opentelemetry.api;
    /* transitive */ requires io.opentelemetry.context;
    /* transitive */ requires io.opentelemetry.sdk.trace;
    /* transitive */ requires java.logging;
    /* transitive */ requires org.seleniumhq.selenium.api;
    /* transitive */ requires org.seleniumhq.selenium.http;
    /* transitive */ requires org.seleniumhq.selenium.json;
    /* transitive */ requires processed.async.http.client;
    /* transitive */ requires processed.jcommander;

    exports org.openqa.selenium.concurrent;
    exports org.openqa.selenium.devtools;
    exports org.openqa.selenium.devtools.events;
    exports org.openqa.selenium.devtools.idealized;
    exports org.openqa.selenium.devtools.idealized.browser.model;
    exports org.openqa.selenium.devtools.idealized.log;
    exports org.openqa.selenium.devtools.idealized.log.model;
    exports org.openqa.selenium.devtools.idealized.runtime.model;
    exports org.openqa.selenium.devtools.idealized.target;
    exports org.openqa.selenium.devtools.idealized.target.model;
    exports org.openqa.selenium.devtools.noop;
    exports org.openqa.selenium.grid.config;
    exports org.openqa.selenium.io;
    exports org.openqa.selenium.os;
    exports org.openqa.selenium.remote;
    exports org.openqa.selenium.remote.codec;
    exports org.openqa.selenium.remote.codec.jwp;
    exports org.openqa.selenium.remote.codec.w3c;
    exports org.openqa.selenium.remote.html5;
    exports org.openqa.selenium.remote.http.netty;
    exports org.openqa.selenium.remote.locators;
    exports org.openqa.selenium.remote.mobile;
    exports org.openqa.selenium.remote.service;
    exports org.openqa.selenium.remote.session;
    exports org.openqa.selenium.remote.tracing;
    exports org.openqa.selenium.remote.tracing.empty;
    exports org.openqa.selenium.remote.tracing.opentelemetry;

    opens org.openqa.selenium.grid.config to org.openqa.selenium.json;
    opens org.openqa.selenium.devtools.idealized.log to org.openqa.selenium.json;
    opens org.openqa.selenium.remote.service to org.openqa.selenium.json;
    opens org.openqa.selenium.remote.http.netty to org.openqa.selenium.json;
    opens org.openqa.selenium.remote to org.openqa.selenium.json;
    opens org.openqa.selenium.remote.codec to org.openqa.selenium.json;
    opens org.openqa.selenium.devtools.idealized.target to org.openqa.selenium.json;
    opens org.openqa.selenium.devtools.idealized.target.model to org.openqa.selenium.json;
    opens org.openqa.selenium.remote.tracing.empty to org.openqa.selenium.json;
    opens org.openqa.selenium.remote.mobile to org.openqa.selenium.json;
    opens org.openqa.selenium.remote.tracing to org.openqa.selenium.json;
    opens org.openqa.selenium.remote.session to org.openqa.selenium.json;
    opens org.openqa.selenium.concurrent to org.openqa.selenium.json;
    opens org.openqa.selenium.devtools.idealized to org.openqa.selenium.json;
    opens org.openqa.selenium.remote.locators to org.openqa.selenium.json;
    opens org.openqa.selenium.remote.html5 to org.openqa.selenium.json;
    opens org.openqa.selenium.devtools.idealized.browser.model to org.openqa.selenium.json;
    opens org.openqa.selenium.devtools.idealized.runtime.model to org.openqa.selenium.json;
    opens org.openqa.selenium.os to org.openqa.selenium.json;
    opens org.openqa.selenium.devtools.events to org.openqa.selenium.json;
    opens org.openqa.selenium.io to org.openqa.selenium.json;
    opens org.openqa.selenium.devtools.noop to org.openqa.selenium.json;
    opens org.openqa.selenium.remote.codec.jwp to org.openqa.selenium.json;
    opens org.openqa.selenium.devtools to org.openqa.selenium.json;
    opens org.openqa.selenium.devtools.idealized.log.model to org.openqa.selenium.json;
    opens org.openqa.selenium.remote.codec.w3c to org.openqa.selenium.json;
    opens org.openqa.selenium.remote.tracing.opentelemetry to org.openqa.selenium.json;

    provides AugmenterProvider with DevToolsProvider;
    provides HttpClient.Factory with NettyClient.Factory;

}

==> selenium-remote-driver-4.8.0.jar: META-INF/versions/9/module-info.java <==
module org.seleniumhq.selenium.remote_driver {
    requires io.netty.buffer;
    requires io.netty.codec.http;
    requires io.netty.common;
    requires io.netty.transport;
    requires io.netty.transport.classes.epoll;
    requires io.netty.transport.classes.kqueue;
    requires io.netty.transport.unix.common;
    requires io.opentelemetry.sdk;
    requires io.opentelemetry.sdk.autoconfigure;
    requires io.opentelemetry.sdk.autoconfigure.spi;
    requires io.opentelemetry.sdk.common;
    requires io.opentelemetry.semconv;
    requires net.bytebuddy;
    requires org.seleniumhq.selenium.manager;
    requires processed.commons.exec;
    requires processed.jtoml;
    /* transitive */ requires com.google.common;
    /* transitive */ requires io.opentelemetry.api;
    /* transitive */ requires io.opentelemetry.context;
    /* transitive */ requires io.opentelemetry.sdk.trace;
    /* transitive */ requires java.logging;
    /* transitive */ requires org.seleniumhq.selenium.api;
    /* transitive */ requires org.seleniumhq.selenium.http;
    /* transitive */ requires org.seleniumhq.selenium.json;
    /* transitive */ requires processed.async.http.client;
    /* transitive */ requires processed.jcommander;

    exports org.openqa.selenium.bidi;
    exports org.openqa.selenium.bidi.browsingcontext;
    exports org.openqa.selenium.bidi.log;
    exports org.openqa.selenium.concurrent;
    exports org.openqa.selenium.devtools;
    exports org.openqa.selenium.devtools.events;
    exports org.openqa.selenium.devtools.idealized;
    exports org.openqa.selenium.devtools.idealized.browser.model;
    exports org.openqa.selenium.devtools.idealized.log;
    exports org.openqa.selenium.devtools.idealized.log.model;
    exports org.openqa.selenium.devtools.idealized.runtime.model;
    exports org.openqa.selenium.devtools.idealized.target;
    exports org.openqa.selenium.devtools.idealized.target.model;
    exports org.openqa.selenium.devtools.noop;
    exports org.openqa.selenium.grid.config;
    exports org.openqa.selenium.io;
    exports org.openqa.selenium.os;
    exports org.openqa.selenium.remote;
    exports org.openqa.selenium.remote.codec;
    exports org.openqa.selenium.remote.codec.jwp;
    exports org.openqa.selenium.remote.codec.w3c;
    exports org.openqa.selenium.remote.html5;
    exports org.openqa.selenium.remote.http.netty;
    exports org.openqa.selenium.remote.locators;
    exports org.openqa.selenium.remote.mobile;
    exports org.openqa.selenium.remote.service;
    exports org.openqa.selenium.remote.session;
    exports org.openqa.selenium.remote.tracing;
    exports org.openqa.selenium.remote.tracing.empty;
    exports org.openqa.selenium.remote.tracing.opentelemetry;

    opens org.openqa.selenium.grid.config to org.openqa.selenium.json;
    opens org.openqa.selenium.devtools.idealized.log to org.openqa.selenium.json;
    opens org.openqa.selenium.remote.service to org.openqa.selenium.json;
    opens org.openqa.selenium.remote.http.netty to org.openqa.selenium.json;
    opens org.openqa.selenium.bidi.log to org.openqa.selenium.json;
    opens org.openqa.selenium.remote to org.openqa.selenium.json;
    opens org.openqa.selenium.remote.codec to org.openqa.selenium.json;
    opens org.openqa.selenium.devtools.idealized.target to org.openqa.selenium.json;
    opens org.openqa.selenium.devtools.idealized.target.model to org.openqa.selenium.json;
    opens org.openqa.selenium.remote.tracing.empty to org.openqa.selenium.json;
    opens org.openqa.selenium.bidi to org.openqa.selenium.json;
    opens org.openqa.selenium.remote.mobile to org.openqa.selenium.json;
    opens org.openqa.selenium.remote.tracing to org.openqa.selenium.json;
    opens org.openqa.selenium.remote.session to org.openqa.selenium.json;
    opens org.openqa.selenium.concurrent to org.openqa.selenium.json;
    opens org.openqa.selenium.devtools.idealized to org.openqa.selenium.json;
    opens org.openqa.selenium.remote.locators to org.openqa.selenium.json;
    opens org.openqa.selenium.remote.html5 to org.openqa.selenium.json;
    opens org.openqa.selenium.bidi.browsingcontext to org.openqa.selenium.json;
    opens org.openqa.selenium.devtools.idealized.browser.model to org.openqa.selenium.json;
    opens org.openqa.selenium.devtools.idealized.runtime.model to org.openqa.selenium.json;
    opens org.openqa.selenium.os to org.openqa.selenium.json;
    opens org.openqa.selenium.devtools.events to org.openqa.selenium.json;
    opens org.openqa.selenium.io to org.openqa.selenium.json;
    opens org.openqa.selenium.devtools.noop to org.openqa.selenium.json;
    opens org.openqa.selenium.remote.codec.jwp to org.openqa.selenium.json;
    opens org.openqa.selenium.devtools to org.openqa.selenium.json;
    opens org.openqa.selenium.devtools.idealized.log.model to org.openqa.selenium.json;
    opens org.openqa.selenium.remote.codec.w3c to org.openqa.selenium.json;
    opens org.openqa.selenium.remote.tracing.opentelemetry to org.openqa.selenium.json;

    provides AugmenterProvider with BiDiProvider, DevToolsProvider;
    provides HttpClient.Factory with NettyClient.Factory;

}
